@@ -5,7 +5,7 @@ each function returns a list containing terms of the sequence"""
 import math
 
 
-def check(n):
+def check(n: int) -> int:
     """checks if arg 'n' is a positive int"""
 
     if not isinstance(n, int):
@@ -15,7 +15,7 @@ def check(n):
     return n
 
 
-def isprime(n):
+def isprime(n: int) -> list[int]:
     """returns True if n is prime"""
 
     if n in range(2, 4):
@@ -27,42 +27,42 @@ def isprime(n):
     return True
 
 
-def whole(n):
+def whole(n: int) -> list[int]:
     """returns the first n Whole Numbers
     0, 1, 2, 3, 4, 5, 6, 7, 8, 9, ..., n-1"""
 
     return list(range(check(n)))
 
 
-def natural(n):
+def natural(n: int) -> list[int]:
     """returns the first n Natural Numbers
     1, 2, 3, 4, 5, 6, 7, 8, 9, 10, ..., n"""
 
     return whole(check(n) + 1)[1:]
 
 
-def negative(n):
+def negative(n: int) -> list[int]:
     """returns the first n Negative Numbers
     -1, -2, -3, -4, -5, -6, -7, -8, -9, -10, ..., -n"""
 
     return [-i for i in natural(n)]
 
 
-def square(n):
+def square(n: int) -> list[int]:
     """returns the first n Perfect Squares
     0, 1, 4, 9, 16, 25, 36, 49, 64, 81, ..., n²"""
 
     return [pow(i, 2) for i in whole(n)]
 
 
-def cube(n):
+def cube(n: int) -> list[int]:
     """returns the first n Perfect Cubes
     0, 1, 8, 27, 64, 125, 216, 343, 512, 729, ..., n³"""
 
     return [pow(i, 3) for i in whole(n)]
 
 
-def prime(n):
+def prime(n: int) -> list[int]:
     """returns the first n Prime Numbers
     2, 3, 5, 7, 11, 13, 17, 19, 23, 29, ..."""
 
@@ -80,7 +80,7 @@ def prime(n):
     return numbers
 
 
-def composite(n):
+def composite(n: int) -> list[int]:
     """returns the first n Composite Numbers
     4, 6, 8, 9, 10, 12, 14, 15, 16, 18, ..."""
 
@@ -96,7 +96,7 @@ def composite(n):
     return numbers
 
 
-def factorial(n):
+def factorial(n: int) -> list[int]:
     """returns the first n Factorial Numbers
     n! = n(n-1)(n-2)...3•2•1"""
 
@@ -111,7 +111,7 @@ def factorial(n):
     return numbers
 
 
-def palindrome(n):
+def palindrome(n: int) -> list[int]:
     """returns the first n Palindrome Numbers
     Palindrome Number:
         a number that remains the same when its digits are reversed"""
@@ -126,7 +126,7 @@ def palindrome(n):
     return numbers
 
 
-def triangular(n):
+def triangular(n: int) -> list[int]:
     """returns the first n terms of the Triangular Number Sequence
     Triangular Number:
         the count of circles arranged in an equilateral triangle with n circles
@@ -136,7 +136,7 @@ def triangular(n):
     return [sum(natural(i)) for i in natural(n)]
 
 
-def tetrahedral(n):
+def tetrahedral(n: int) -> list[int]:
     """returns the first n terms of the Tetrahedral Number Sequence
     Tetrahedral Number:
         the count of spheres arranged in a tetrahedron with n spheres on a side
@@ -145,7 +145,7 @@ def tetrahedral(n):
     return [sum(triangular(i)) for i in natural(n)]
 
 
-def octahedral(n):
+def octahedral(n: int) -> list[int]:
     """returns the first n terms of the Octahedral Number Sequence
     Octahedral Number:
         the count of spheres arranged in an octahedron with n spheres on a side
@@ -154,7 +154,7 @@ def octahedral(n):
     return [i * (2*pow(i, 2) + 1) // 3 for i in natural(n)]
 
 
-def dodecahedral(n):
+def dodecahedral(n: int) -> list[int]:
     """returns the first n terms of the Dodecahedral Number Sequence
     Dodecahedral Number:
         the count of spheres arranged in a dodecahedron with n spheres on a side
@@ -163,7 +163,7 @@ def dodecahedral(n):
     return [i * (3*i - 1) * (3*i - 2) // 2 for i in natural(n)]
 
 
-def icosahedral(n):
+def icosahedral(n: int) -> list[int]:
     """returns the first n terms of the Icosahedral Number Sequence
     Icosahedral Number:
         the count of spheres arranged in an icosahedron with n spheres on a side
@@ -172,7 +172,7 @@ def icosahedral(n):
     return [i * (5 * pow(i, 2) - 5*i + 2) // 2 for i in natural(n)]
 
 
-def sq_pyramid(n):
+def sq_pyramid(n: int) -> list[int]:
     """returns the first n terms of the Square-Pyramidal Number Sequence
     Square-Pyramidal Number:
         the count of spheres arranged in a square pyramid with n spheres on a
@@ -182,7 +182,7 @@ def sq_pyramid(n):
     return [sum(square(i + 1)) for i in natural(n)]
 
 
-def star(n):
+def star(n: int) -> list[int]:
     """returns the first n terms of the Star Number Sequence
     Star Number:
         the count of dots arranged in a 6-pointed star with n dots on a side
@@ -192,7 +192,7 @@ def star(n):
     return [(6 * i * (i-1)) + 1 for i in natural(n)]
 
 
-def stella_octangula(n):
+def stella_octangula(n: int) -> list[int]:
     """returns the first n terms of the Stella-Octangula Number Sequence
     Stella-Octangula Number:
         the count of spheres arranged in a stella octangula with n spheres on a
@@ -202,7 +202,7 @@ def stella_octangula(n):
     return [i * ((2 * pow(i, 2)) - 1) for i in whole(n)]
 
 
-def central_polygon(n):
+def central_polygon(n: int) -> list[int]:
     """returns the first n terms of the Central Polygon Number Sequence
     Central Polygon Number:
         the maximum number of pieces of a circular disc that can be made with
@@ -212,7 +212,7 @@ def central_polygon(n):
     return [(pow(n, 2) + n+2) // 2 for n in whole(n)]
 
 
-def magic_constants(n):
+def magic_constants(n: int) -> list[int]:
     """returns the first n Magic Constants
     Magic Constant:
         Mₙ = n(n²+1) / 2"""
@@ -220,7 +220,7 @@ def magic_constants(n):
     return [i * (pow(i, 2)+1) // 2 for i in whole(n)]
 
 
-def woodall(n):
+def woodall(n: int) -> list[int]:
     """returns the first n terms of the Woodall Number Sequence
     Woodall Number:
         number of the form 2ⁿn - 1
@@ -229,7 +229,7 @@ def woodall(n):
     return [(i * pow(2, i)) - 1 for i in natural(n)]
 
 
-def cullen(n):
+def cullen(n: int) -> list[int]:
     """returns the first n terms of the Cullen Number Sequence
     Cullen Number:
         number of the form 2ⁿn + 1
@@ -238,7 +238,7 @@ def cullen(n):
     return [(i * pow(2, i)) + 1 for i in whole(n)]
 
 
-def pronic(n):
+def pronic(n: int) -> list[int]:
     """returns the first n terms of the Pronic Number Sequence
     Pronic Number:
         number that is product of two consecutive whole numbers
@@ -247,7 +247,7 @@ def pronic(n):
     return [i * (i+1) for i in whole(n)]
 
 
-def arithmetic(n):
+def arithmetic(n: int) -> list[int]:
     """returns the first n terms of the Arithmetic Number Sequence
     Arithmetic Number:
         a number such that the average of its positive divisors is also an
@@ -272,7 +272,7 @@ def arithmetic(n):
     return numbers
 
 
-def carol(n):
+def carol(n: int) -> list[int]:
     """returns the first n terms of the Carol Number Sequence
     Carol Number:
         number such that bin(n) is of the form (n-2) 1s + 0 + (n+1) 1s
@@ -281,7 +281,7 @@ def carol(n):
     return [pow(4, i) - pow(2, i+1) - 1 for i in natural(n)]
 
 
-def perfect(n):
+def perfect(n: int) -> list[int]:
     """returns the first n terms of the Perfect Number Sequence
     Perfect Number:
         number that is equal to sum of its positive divisors excluding itself
@@ -302,7 +302,7 @@ def perfect(n):
     return numbers
 
 
-def undulating(n):
+def undulating(n: int) -> list[int]:
     """returns the first n terms of the Undulating Number Sequence
     Undulating Number:
         number of the form ABABAB... (A ≠ B)"""
@@ -320,7 +320,7 @@ def undulating(n):
     return numbers
 
 
-def pascal(n):
+def pascal(n: int) -> list[int]:
     """returns the n-th row of the Pascal's triangle
     n-th row of Pascal's Triangle is given by:
         Pₙ = ⁿCᵣ for r ∈ range(n+1)"""
@@ -328,7 +328,7 @@ def pascal(n):
     return [math.comb(n, r) for r in range(n+1)]
 
 
-def gould(n):
+def gould(n: int) -> list[int]:
     """returns the first n terms of the Gould Sequence
     Gould Number:
         the count of odd numbers in the n-th row of pascal's triangle
@@ -346,7 +346,7 @@ def gould(n):
     return numbers
 
 
-def central_binomial(n):
+def central_binomial(n: int) -> list[int]:
     """returns the first n Central Binomial Coefficients
     Central Binomial Coefficient:
         the coefficient that shows up exactly in the middle of the even numbered
@@ -355,7 +355,7 @@ def central_binomial(n):
     return [math.comb(2*i, i) for i in whole(n)]
 
 
-def catalan(n):
+def catalan(n: int) -> list[int]:
     """returns the first n terms of the Catalan Number Sequence
     Catalan Number:
         number of the form (2n!) / (n!(n+1)!)
@@ -364,7 +364,7 @@ def catalan(n):
     return [math.comb(2*i, i) // (i+1) for i in whole(n)]
 
 
-def van_eck(n):
+def van_eck(n: int) -> list[int]:
     """returns first n terms of the Van-Eck Sequence
     Van-Eck Sequence is defined as:
         Tₙ = 0 if n == 0
@@ -392,7 +392,7 @@ def van_eck(n):
     return numbers
 
 
-def recaman(n):
+def recaman(n: int) -> list[int]:
     """returns first n terms of the Recamán Sequence
     Recamán Sequence is defined as:
         Tₙ = 0 if n == 0
@@ -411,7 +411,7 @@ def recaman(n):
     return numbers
 
 
-def look_say(n):
+def look_say(n: int) -> list[int]:
     """returns first n terms of the Look and Say Sequence
     Look and Say Sequence is defined as:
         Tₙ = 0 if n == 0
@@ -439,7 +439,7 @@ def look_say(n):
     return numbers
 
 
-def aronson(n):
+def aronson(n: int) -> list[int]:
     """returns the first n terms of the Aronson Sequence
     Aronson Sequence is defined as:
         the index of English Letter "T" or "t" in the sentence
@@ -490,7 +490,7 @@ def aronson(n):
     return numbers
 
 
-def baum_sweet(n):
+def baum_sweet(n: int) -> list[int]:
     """returns the first n terms of the Baum-Sweet Sequence
     Baum Sweet Sequence is defined as:
         Tₙ = 1 if bin(n) contains no block of consecutive 0s of odd length
@@ -518,7 +518,7 @@ def baum_sweet(n):
     return numbers
 
 
-def fibonacci(n):
+def fibonacci(n: int) -> list[int]:
     """returns first n terms of the Fibonacci Sequence
     Fibonacci Sequence is defined as:
         Fₙ = 0 if n == 0
@@ -536,7 +536,7 @@ def fibonacci(n):
     return numbers
 
 
-def negafibonacci(n):
+def negafibonacci(n: int) -> list[int]:
     """returns first n terms of the NegaFibonacci Sequence
     NegaFibonacci Sequence is defined as:
         F₋ₙ = (-1)ⁿ⁺¹Fₙ
@@ -545,7 +545,7 @@ def negafibonacci(n):
     return [pow(-1, i+1) * fibonacci(n)[i] for i in range(n)]
 
 
-def tribonacci(n):
+def tribonacci(n: int) -> list[int]:
     """returns first n terms of the Tribonacci Sequence
     Tribonacci Sequence is defined as:
         Tₙ = 0 if n in (0, 1)
@@ -563,7 +563,7 @@ def tribonacci(n):
     return numbers
 
 
-def negatribonacci(n):
+def negatribonacci(n: int) -> list[int]:
     """returns the first n terms of the NegaTribonacci Sequence
     NegaTribonacci Sequence is defined as:
         T₋ₙ = (-1)ⁿ⁺¹Tₙ
@@ -572,7 +572,7 @@ def negatribonacci(n):
     return [pow(-1, i+1) * tribonacci(n)[i] for i in range(n)]
 
 
-def lucas(n):
+def lucas(n: int) -> list[int]:
     """returns the first n terms of the Lucas Sequence
     Lucas Sequence is defined as:
         Lₙ = 2 if n == 0
@@ -590,7 +590,7 @@ def lucas(n):
     return numbers
 
 
-def negalucas(n):
+def negalucas(n: int) -> list[int]:
     """returns first n terms of the NegaLucas Sequence
     NegaFibonacci Sequence is defined as:
         L₋ₙ = (-1)ⁿLₙ
@@ -599,7 +599,7 @@ def negalucas(n):
     return [pow(-1, i) * lucas(n)[i] for i in range(n)]
 
 
-def supergolden(n):
+def supergolden(n: int) -> list[int]:
     """returns the first n terms of the Supergolden Sequence
     Supergolden Sequence is defined as:
         Sₙ = 1 if n in (0, 1, 2)
@@ -616,7 +616,7 @@ def supergolden(n):
     return numbers
 
 
-def padovan(n):
+def padovan(n: int) -> list[int]:
     """returns first n terms of the Padovan Sequence
     Padovan Sequence is defined as:
         Pₙ = 1 if n in (0, 1, 2)
@@ -633,7 +633,7 @@ def padovan(n):
     return numbers
 
 
-def perrin(n):
+def perrin(n: int) -> list[int]:
     """returns first n terms of the Perrin Sequence
     Perrin Sequence is defined as:
         Pₙ = 3 if n == 0
@@ -652,7 +652,7 @@ def perrin(n):
     return numbers
 
 
-def pell(n):
+def pell(n: int) -> list[int]:
     """returns the first n terms of the Pell Sequence
     Pell Sequence is defined as:
         Pₙ = 0 if n == 0
@@ -670,7 +670,7 @@ def pell(n):
     return numbers
 
 
-def jacobstathal(n):
+def jacobstathal(n: int) -> list[int]:
     """returns the first n terms of the Jacobstathal Sequence
     Jacobstathal Sequence is defined as:
         Jₙ = 0 if n == 0
@@ -688,7 +688,7 @@ def jacobstathal(n):
     return numbers
 
 
-def sylvester(n):
+def sylvester(n: int) -> list[int]:
     """returns the first n terms of the Sylvester Sequence
     Sylvester Sequence is defined as:
         Sₙ = 2 if n == 0
@@ -705,7 +705,7 @@ def sylvester(n):
     return numbers
 
 
-def euclid_mullin(n):
+def euclid_mullin(n: int) -> list[int]:
     """returns the first n terms of the Euclid-Mullin Sequence
     Euclid-Mullin Sequence is defined as:
         Tₙ = 2 if n == 1
@@ -732,7 +732,7 @@ def euclid_mullin(n):
     return numbers
 
 
-def sophie_germain(n):
+def sophie_germain(n: int) -> list[int]:
     """returns the first n terms of the Sophie-Germain Prime Number Sequence
     Sophie Germain Prime Number:
         prime number x such that 2x + 1 is also prime"""
@@ -747,7 +747,7 @@ def sophie_germain(n):
     return numbers
 
 
-def circular_prime(n):
+def circular_prime(n: int) -> list[int]:
     """returns the first n terms of the Circular-Prime Number Sequence
     Circular Prime Number:
         number such that all of its cyclic permutations are prime"""
@@ -787,7 +787,7 @@ def circular_prime(n):
     return numbers
 
 
-def prime_powers(n):
+def prime_powers(n: int) -> list[int]:
     """returns the first n Prime Power Numbers
     Prime Power Number:
         number of the form xⁿ where x is prime and n is any positive integer"""
@@ -816,7 +816,7 @@ def prime_powers(n):
     return numbers
 
 
-def semiprime(n):
+def semiprime(n: int) -> list[int]:
     """returns the first n Semi-Prime Numbers
     Semi-Prime Number:
         the product of two prime numbers, not necessarily distinct"""
@@ -845,7 +845,7 @@ def semiprime(n):
     return numbers
 
 
-def sphenic(n):
+def sphenic(n: int) -> list[int]:
     """returns the first n terms of the Sphenic Number Sequence
     Sphenic Number:
         number that is the product of three distinct primes"""
